dashcam_video_player

A high-performance texture-based RTSP video player plugin for Flutter powered by ExoPlayer and MobileVLCKit.

This package is intended for internal organizational use only.
If you are not associated with the organization using this package, some functionality or streams may not be accessible.

Features

  • RTSP streaming support
  • Texture-based rendering
  • Android ExoPlayer integration
  • iOS MobileVLCKit integration
  • Low-latency playback

Platform Support

Platform Supported
Android
iOS